// Copyright (c) 2002 David Muse
// See the COPYING file for more information.

	private:
		bool	initialize(const char *hostname,
					const char *address,
					int32_t len, int32_t type);
		hostentryprivate	*pvt;
